Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaxim Pimenov <m@maps.me>2016-04-29 18:29:50 +0300
committerAlex Zolotarev <alex@maps.me>2016-05-01 10:28:03 +0300
commit098a645f8b7010bfeea5b8e8e338d428f2d8540e (patch)
treeddbbae69230092dedc29ec006018130b26147bf2 /indexer/new_feature_categories.hpp
parentc847bea4e820aa9402069401e34ca3ab6a3a8dc4 (diff)
[editor] Log searches of categories for new features.
Diffstat (limited to 'indexer/new_feature_categories.hpp')
-rw-r--r--indexer/new_feature_categories.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indexer/new_feature_categories.hpp b/indexer/new_feature_categories.hpp
index 1191564539..5bdd544f56 100644
--- a/indexer/new_feature_categories.hpp
+++ b/indexer/new_feature_categories.hpp
@@ -36,11 +36,11 @@ public:
// If |lang| is not supported, "en" is used.
void AddLanguage(string lang);
// Returns names (in language |lang|) and types of categories that have a synonym containing
// the substring |query| (in any language that was added before).
// If |lang| is not supported, "en" is used.
// The returned list is sorted.
- TNames Search(string const & query, string lang) const;
+ TNames Search(string const & query, string const & queryLang) const;
// Returns all registered names of categories in language |lang| and
// types corresponding to these names. The language must have been added before.
@@ -36,11 +36,11 @@ public:
// If |lang| is not supported, "en" is used.
void AddLanguage(string lang);
- // Returns names (in language |lang|) and types of categories that have a synonym containing
+ // Returns names (in language |queryLang|) and types of categories that have a synonym containing
// the substring |query| (in any language that was added before).
@@ -36,11 +36,11 @@ public:
// the substring |query| (in any language that was added before).
- // If |lang| is not supported, "en" is used.
+ // If |queryLang| is not supported, "en" is used.
// The returned list is sorted.